'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var escapeCell = function escapeCell(str) {
    return str.replace(/\n/g, ' ').replace(/\|/g, '\\|');
};


var escape = function escape(str) {
    return escapeCell(str).replace(/[_\][]/g, function (match) {
        return '\\' + match;
    }).replace(/>/g, '&gt;').replace(/</g, '&lt;').replace(/\*/g, '&ast;');
};

var buildValue = function buildValue(value) {
    return '`' + escapeCell(String(value.value)) + '`';
};

var buildNativeType = function buildNativeType(type) {
    if (Array.isArray(type.value)) {
        var stringType = type.value.map(function (typeValue) {
            return typeValue.name || String(typeValue.value);
        }).join(' | ');

        return escape(stringType);
    } else if (type.name) {
        return escape(type.name);
    }

    return '';
};

var buildFlowType = function buildFlowType(type) {
    return escape(type.raw || type.name);
};

var buildProp = function buildProp(_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        name = _ref2[0],
        prop = _ref2[1];

    return '| ' + [
    /* Name        */'**' + name + '**',
    /* Type        */prop.flowType ? buildFlowType(prop.flowType) : prop.type ? buildNativeType(prop.type) : '',
    /* Required    */prop.required ? 'yes' : 'no',
    /* Default     */prop.defaultValue ? buildValue(prop.defaultValue) : '-',
    /* Description */prop.description ? escapeCell(prop.description) : ''].join(' | ') + ' |';
};

var buildProps = function buildProps(props) {
    return '\n| Name | Type | Required | Default | Description |\n|------|------|:--------:|---------|-------------|\n' + Object.entries(props).map(buildProp).join('\n');
};

exports.default = function (docgenInfo) {
    return '\n# ' + (docgenInfo.displayName || 'Unknown') + '\n' + (docgenInfo.description || '') + '\n' + (docgenInfo.props ? buildProps(docgenInfo.props) : '');
};
//# sourceMappingURL=buildMarkdown.js.map